@@ -47,6 +47,9 @@ module ClassyPrelude
     , traceShowM
       -- ** Time (since 0.6.1)
     , module Data.Time
+#if MIN_VERSION_time(1,10,0)
+    , parseTime
+#endif
       -- ** Generics (since 0.8.1)
     , Generic
       -- ** Transformers (since 0.9.4)
@@ -190,17 +193,21 @@ import Data.Time
     , toGregorian
     , fromGregorian
     , formatTime
+#if !MIN_VERSION_time(1,10,0)
     , parseTime
+#endif
     , parseTimeM
     , getCurrentTime
     , defaultTimeLocale
     )
+import qualified Data.Time as Time
 
 import qualified Data.Set as Set
 import qualified Data.Map as Map
 import qualified Data.HashSet as HashSet
 
 import GHC.Generics (Generic)
+import GHC.Stack (HasCallStack)
 
 import Control.Monad.Primitive (primToPrim, primToIO, primToST)
 import Data.Primitive.MutVar
@@ -218,10 +225,6 @@ import Control.Concurrent.STM.TMChan
 import Control.Concurrent.STM.TMQueue
 import qualified Control.Concurrent
 
-#if MIN_VERSION_base(4,9,0)
-import GHC.Stack (HasCallStack)
-#endif
-
 tshow :: Show a => a -> Text
 tshow = fromList . Prelude.show
 
@@ -334,11 +337,7 @@ sortWith f = sortBy $ comparing f
 -- @"Prelude".'Prelude.undefined'@.
 --
 -- Since 0.5.5
-#if MIN_VERSION_base(4,9,0)
 undefined :: HasCallStack => a
-#else
-undefined :: a
-#endif
 undefined = error "ClassyPrelude.undefined"
 {-# DEPRECATED undefined "It is highly recommended that you either avoid partial functions or provide meaningful error messages" #-}
 
@@ -627,3 +626,16 @@ getContents = liftIO LTextIO.getContents
 -- @since 1.3.1
 interact :: MonadIO m => (LText -> LText) -> m ()
 interact = liftIO . LTextIO.interact
+
+
+#if MIN_VERSION_time(1,10,0)
+parseTime 
+  :: Time.ParseTime t
+  => Time.TimeLocale -- ^ Time locale.
+  -> String -- ^ Format string.
+  -> String -- ^ Input string.
+  -> Maybe t -- ^ The time value, or 'Nothing' if the input could not be parsed using the given format.
+parseTime = parseTimeM True
+#endif
+
+
